@@ -5,6 +5,7 @@ Modular, class-based display system for startup information.
 """
 
 from .base import BaseDisplayManager
+from .grpc_display import GRPCDisplayManager
 from .ngrok import NgrokDisplayManager
 from .startup import StartupDisplayManager
 
@@ -12,4 +13,5 @@ __all__ = [
     "BaseDisplayManager",
     "StartupDisplayManager",
     "NgrokDisplayManager",
+    "GRPCDisplayManager",
 ]
