@@ -46,13 +46,18 @@ Example:
 from .config import (
     ActionConfig,
     AdminConfig,
+    BackgroundTaskConfig,
     BadgeField,
     BooleanField,
     CurrencyField,
     DateTimeField,
+    DocumentationConfig,
     FieldConfig,
     FieldsetConfig,
     ImageField,
+    MarkdownField,
+    ResourceConfig,
+    ShortUUIDField,
     TextField,
     UserField,
 )
@@ -71,6 +76,7 @@ from .icons import IconCategories, Icons
 from .utils import (
     CounterBadge,
     DateTimeDisplay,
+    MarkdownRenderer,
     MoneyDisplay,
     ProgressBadge,
     StatusBadge,
@@ -101,12 +107,17 @@ __all__ = [
     "FieldConfig",
     "FieldsetConfig",
     "ActionConfig",
+    "ResourceConfig",
+    "BackgroundTaskConfig",
+    "DocumentationConfig",
     # Specialized Field Types
     "BadgeField",
     "BooleanField",
     "CurrencyField",
     "DateTimeField",
     "ImageField",
+    "MarkdownField",
+    "ShortUUIDField",
     "TextField",
     "UserField",
     # Advanced
@@ -121,6 +132,7 @@ __all__ = [
     "StatusBadge",
     "ProgressBadge",
     "CounterBadge",
+    "MarkdownRenderer",
     # Decorators
     "computed_field",
     "badge_field",
