@@ -3,6 +3,7 @@ PydanticAdmin - Declarative admin base class.
 """
 
 import logging
+from pathlib import Path
 from typing import Any, List, Optional
 
 from django.utils.safestring import mark_safe
@@ -24,17 +25,24 @@ def _get_base_admin_class():
 
     MRO (Method Resolution Order):
         UnfoldImportExportModelAdmin
-          └─ ImportExportModelAdmin  # Import/Export functionality
-          └─ UnfoldModelAdmin        # Unfold UI
+          └─ UnfoldModelAdmin        # Unfold UI (first for template priority)
+          └─ ImportExportMixin       # Import/Export functionality (django_cfg custom)
                └─ Django ModelAdmin
 
     This ensures both Unfold UI and Import/Export work together seamlessly.
+
+    Uses django_cfg's custom ImportExportMixin which includes:
+    - Custom templates for proper Unfold styling
+    - Unfold forms (ImportForm, ExportForm)
+    - Properly styled import/export buttons
     """
-    from import_export.admin import ImportExportModelAdmin
+    # Use original ImportExportModelAdmin with Unfold
+    from import_export.admin import ImportExportModelAdmin as BaseImportExportModelAdmin
     from unfold.admin import ModelAdmin as UnfoldModelAdmin
 
-    class UnfoldImportExportModelAdmin(ImportExportModelAdmin, UnfoldModelAdmin):
-        """Combined Unfold + Import/Export admin base class."""
+    class UnfoldImportExportModelAdmin(BaseImportExportModelAdmin, UnfoldModelAdmin):
+        """Combined Import/Export + Unfold admin base class."""
+        # Import/Export should come FIRST in MRO to get its get_urls() method
         pass
 
     return UnfoldImportExportModelAdmin
@@ -122,8 +130,170 @@ class PydanticAdminMixin:
         cls.preserve_filters = config.preserve_filters
 
         # Import/Export configuration
-        if config.import_export_enabled and config.resource_class:
-            cls.resource_class = config.resource_class
+        if config.import_export_enabled:
+            # Set import/export template
+            cls.change_list_template = 'admin/import_export/change_list_import_export.html'
+
+            if config.resource_class:
+                # Use provided resource class
+                cls.resource_class = config.resource_class
+            else:
+                # Auto-generate resource class
+                cls.resource_class = cls._generate_resource_class(config)
+
+            # Override changelist_view to add import/export context
+            original_changelist_view = cls.changelist_view
+
+            def changelist_view_with_import_export(self, request, extra_context=None):
+                if extra_context is None:
+                    extra_context = {}
+                extra_context['has_import_permission'] = self.has_import_permission(request)
+                extra_context['has_export_permission'] = self.has_export_permission(request)
+                return original_changelist_view(self, request, extra_context)
+
+            cls.changelist_view = changelist_view_with_import_export
+
+        # Documentation configuration
+        if config.documentation:
+            cls._setup_documentation(config)
+
+    @classmethod
+    def _setup_documentation(cls, config: AdminConfig):
+        """
+        Setup documentation using unfold's template hooks.
+
+        Uses unfold's built-in hooks:
+        - list_before_template: Shows documentation before changelist table
+        - change_form_before_template: Shows documentation before fieldsets
+        """
+        doc_config = config.documentation
+
+        # Set unfold template hooks
+        if doc_config.show_on_changelist:
+            cls.list_before_template = "django_admin/documentation_block.html"
+
+        if doc_config.show_on_changeform:
+            cls.change_form_before_template = "django_admin/documentation_block.html"
+
+        # Store documentation config for access in views
+        cls.documentation_config = doc_config
+
+    def _get_app_path(self) -> Optional[Path]:
+        """
+        Detect the app path for relative file resolution.
+
+        Returns:
+            Path to the app directory or None
+        """
+        if not self.model:
+            return None
+
+        try:
+            # Get app label from model
+            app_label = self.model._meta.app_label
+
+            # Try to get app config
+            from django.apps import apps
+            app_config = apps.get_app_config(app_label)
+
+            if app_config and hasattr(app_config, 'path'):
+                return Path(app_config.path)
+        except Exception as e:
+            logger.warning(f"Could not detect app path for {self.model}: {e}")
+
+        return None
+
+    @classmethod
+    def _generate_resource_class(cls, config: AdminConfig):
+        """
+        Auto-generate a ModelResource class for import/export.
+
+        Uses ResourceConfig if provided, otherwise generates basic Resource.
+        """
+        from import_export import resources
+
+        target_model = config.model
+        resource_config = config.resource_config
+
+        # Determine fields to include
+        if resource_config and resource_config.fields:
+            # Use explicitly specified fields
+            model_fields = resource_config.fields
+        else:
+            # Auto-detect fields from model
+            model_fields = []
+            for field in target_model._meta.get_fields():
+                # Skip relations and auto fields that shouldn't be imported
+                if field.concrete and not field.many_to_many:
+                    # Skip password fields for security
+                    if 'password' not in field.name.lower():
+                        model_fields.append(field.name)
+
+        # Apply exclusions if specified
+        if resource_config and resource_config.exclude:
+            model_fields = [f for f in model_fields if f not in resource_config.exclude]
+
+        # Build Meta attributes
+        meta_attrs = {
+            'model': target_model,
+            'fields': tuple(model_fields),
+        }
+
+        # Add ResourceConfig settings
+        if resource_config:
+            meta_attrs['import_id_fields'] = resource_config.import_id_fields
+            meta_attrs['skip_unchanged'] = resource_config.skip_unchanged
+            meta_attrs['report_skipped'] = resource_config.report_skipped
+            meta_attrs['use_transactions'] = resource_config.use_transactions
+
+            if resource_config.export_order:
+                meta_attrs['export_order'] = tuple(resource_config.export_order)
+        else:
+            # Default settings
+            meta_attrs['import_id_fields'] = ['id'] if 'id' in model_fields else []
+            meta_attrs['skip_unchanged'] = True
+            meta_attrs['report_skipped'] = True
+
+        # Create Meta class
+        ResourceMeta = type('Meta', (), meta_attrs)
+
+        # Build Resource class attributes (methods + Meta)
+        resource_attrs = {'Meta': ResourceMeta}
+
+        # Add hooks from ResourceConfig
+        if resource_config:
+            # before_import hook
+            if resource_config.before_import:
+                hook = resource_config.get_callable('before_import')
+                if hook:
+                    resource_attrs['before_import'] = hook
+
+            # after_import hook
+            if resource_config.after_import:
+                hook = resource_config.get_callable('after_import')
+                if hook:
+                    resource_attrs['after_import'] = hook
+
+            # before_import_row hook
+            if resource_config.before_import_row:
+                hook = resource_config.get_callable('before_import_row')
+                if hook:
+                    resource_attrs['before_import_row'] = hook
+
+            # after_import_row hook
+            if resource_config.after_import_row:
+                hook = resource_config.get_callable('after_import_row')
+                if hook:
+                    resource_attrs['after_import_row'] = hook
+
+        # Create Resource class
+        AutoGeneratedResource = type(
+            f'{target_model.__name__}Resource',
+            (resources.ModelResource,),
+            resource_attrs
+        )
+
+        return AutoGeneratedResource
 
     @classmethod
     def _build_list_display(cls, config: AdminConfig) -> List[str]:
@@ -333,17 +503,69 @@ class PydanticAdminMixin:
 
         return tuple(filtered_fieldsets)
 
+    def changelist_view(self, request, extra_context=None):
+        """Override to add documentation context to changelist."""
+        if extra_context is None:
+            extra_context = {}
+
+        # Add documentation context if configured
+        if hasattr(self, 'documentation_config') and self.documentation_config:
+            doc_config = self.documentation_config
+            app_path = self._get_app_path()
+
+            if doc_config.show_on_changelist:
+                extra_context['documentation_config'] = doc_config
+                extra_context['documentation_sections'] = doc_config.get_sections(app_path)
+
+                # Add management commands if enabled
+                if doc_config.show_management_commands:
+                    extra_context['management_commands'] = doc_config._discover_management_commands(app_path)
+
+                # Add Mermaid resources if plugins enabled
+                if doc_config.enable_plugins:
+                    from django_cfg.modules.django_admin.utils.markdown.mermaid_plugin import get_mermaid_resources
+                    extra_context['mermaid_resources'] = get_mermaid_resources()
+
+        return super().changelist_view(request, extra_context)
+
+    def changeform_view(self, request, object_id=None, form_url='', extra_context=None):
+        """Override to add documentation context to changeform."""
+        if extra_context is None:
+            extra_context = {}
+
+        # Add documentation context if configured
+        if hasattr(self, 'documentation_config') and self.documentation_config:
+            doc_config = self.documentation_config
+            app_path = self._get_app_path()
+
+            if doc_config.show_on_changeform:
+                extra_context['documentation_config'] = doc_config
+                extra_context['documentation_sections'] = doc_config.get_sections(app_path)
+
+                # Add management commands if enabled
+                if doc_config.show_management_commands:
+                    extra_context['management_commands'] = doc_config._discover_management_commands(app_path)
+
+                # Add Mermaid resources if plugins enabled
+                if doc_config.enable_plugins:
+                    from django_cfg.modules.django_admin.utils.markdown.mermaid_plugin import get_mermaid_resources
+                    extra_context['mermaid_resources'] = get_mermaid_resources()
+
+        return super().changeform_view(request, object_id, form_url, extra_context)
+
     def formfield_for_dbfield(self, db_field, request, **kwargs):
         """
         Override form field for specific database field types.
 
         Automatically detects and customizes encrypted fields from django-crypto-fields.
+        Respects the show_encrypted_fields_as_plain_text setting from AdminConfig.
+        Uses custom widgets with copy-to-clipboard functionality.
         """
         # Check if this is an EncryptedTextField or EncryptedCharField
         field_class_name = db_field.__class__.__name__
         if 'Encrypted' in field_class_name and ('TextField' in field_class_name or 'CharField' in field_class_name):
             from django import forms
-            from django.forms.widgets import PasswordInput
+            from ..widgets import EncryptedFieldWidget, EncryptedPasswordWidget
 
             # Determine placeholder based on field name
             placeholder = "Enter value"
@@ -354,16 +576,25 @@ class PydanticAdminMixin:
             elif 'passphrase' in db_field.name.lower():
                 placeholder = "Enter Passphrase (if required)"
 
-            # Return CharField with PasswordInput widget for security
-            # render_value=True shows masked value (••••••) after save
+            # Widget attributes
+            widget_attrs = {
+                'placeholder': placeholder,
+            }
+
+            # Decide widget based on config
+            show_plain_text = getattr(self.config, 'show_encrypted_fields_as_plain_text', False)
+
+            if show_plain_text:
+                # Show as plain text with copy button
+                widget = EncryptedFieldWidget(attrs=widget_attrs, show_copy_button=True)
+            else:
+                # Show as password (masked) with copy button
+                # render_value=True shows masked value (••••••) after save
+                widget = EncryptedPasswordWidget(attrs=widget_attrs, render_value=True, show_copy_button=True)
+
+            # Return CharField with appropriate widget
             return forms.CharField(
-                widget=PasswordInput(
-                    attrs={
-                        'placeholder': placeholder,
-                        'class': 'appearance-none block w-full bg-gray-200 text-gray-700 border border-gray-200 rounded py-3 px-4 leading-tight focus:outline-none focus:bg-white focus:border-gray-500'
-                    },
-                    render_value=True  # Show masked value after save
-                ),
+                widget=widget,
                 required=not db_field.blank and not db_field.null,
                 help_text=db_field.help_text or "This field is encrypted at rest",
                 label=db_field.verbose_name if hasattr(db_field, 'verbose_name') else db_field.name.replace('_', ' ').title()
