@@ -4,6 +4,8 @@ Configuration models for declarative Django Admin.
 
 from .action_config import ActionConfig
 from .admin_config import AdminConfig
+from .background_task_config import BackgroundTaskConfig
+from .documentation_config import DocumentationConfig, DocumentationSection
 from .field_config import (
     FieldConfig,
     BadgeField,
@@ -11,22 +13,31 @@ from .field_config import (
     CurrencyField,
     DateTimeField,
     ImageField,
+    MarkdownField,
+    ShortUUIDField,
     TextField,
     UserField,
 )
 from .fieldset_config import FieldsetConfig
+from .resource_config import ResourceConfig
 
 __all__ = [
     "AdminConfig",
     "FieldConfig",
     "FieldsetConfig",
     "ActionConfig",
+    "ResourceConfig",
+    "BackgroundTaskConfig",
+    "DocumentationConfig",
+    "DocumentationSection",
     # Specialized Field Types
     "BadgeField",
     "BooleanField",
     "CurrencyField",
     "DateTimeField",
     "ImageField",
+    "MarkdownField",
+    "ShortUUIDField",
     "TextField",
     "UserField",
 ]
